# Configuring the Microsoft Teams Channel
### On this page
  * [Workspace Notifications](https://help.sap.com/docs/leanix/ea/configuring-microsoft-teams-channel#workspace-notifications)
  * [Fact Sheet Update Details](https://help.sap.com/docs/leanix/ea/configuring-microsoft-teams-channel#fact-sheet-update-details)


SAP LeanIX provides notifications in Microsoft Teams with the Microsoft Teams integration.
